﻿// --------------------------------------------------------------------------------------
//
// UltraRadar.cs                                                  Ulrich Müller  22.05.08
//                                                                PCS1700 C# 2005 Express
// Radarturm : Neuauflage von radar.htm aus 1998 
//       unter Einsatz des Ultraschallsensors vom ROBO Explorer
//       Basis ist die Assembly FishFace2005.DLL
//
// --------------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using FishFace40;

namespace UltraRadar {
  public partial class UltraRadar : Form {
    
    const int mTurm     = (int)Out.M1;
    const int iTurm     = mTurm - 1;
    const int mSensor   = (int)Out.M2;
    const int iSensor   = mSensor - 1;
    const Inp dSensor   = Inp.D1;
    const int incTurm   = 30;
    const int disNah    = 15;
    const int disMittel = 75;

    FishRobot ft = new FishRobot(new int[,] { { mTurm, 180 }, { mSensor, 99 }});
    Graphics rs;
    SolidBrush Farbe;

    private void PositionAusgabe(object sender, int[] actPos) {
      if ((actPos[iTurm] % incTurm) > 0) return;
      string Pos = "Position : ";
      for (int i = 0; i < actPos.Length - 1; i++) {
        Pos += actPos[i].ToString("000") + " - ";
      }
      Pos += actPos[actPos.Length - 1].ToString("000");

      int dis = ft.GetDistance(dSensor);
      lblPosition.Text = Pos + "   Wert : " + dis.ToString();
      if (actPos.Length == 2) {
        if (dis < disNah)         Farbe = new SolidBrush(Color.Red);
        else if (dis < disMittel) Farbe = new SolidBrush(Color.Yellow);
        else                      Farbe = new SolidBrush(Color.Green);
        rs.FillRectangle(Farbe, actPos[iTurm] * 2,
                                actPos[iSensor] * 2, 50, 4);
      }
    }

    private void Action() {
      rs = picAnzeige.CreateGraphics();
      rs.Clear(Color.Black);
      
      lblPosition.Text = "Bei der Arbeit";
      while (!ft.Finish()) {
        lblStatus.Text = "Home";
        ft.MoveHome();
        while(ft.MotCntl[iTurm].actPos < ft.MotCntl[iTurm].maxPos && !ft.Finish()){
          lblStatus.Text = "Scan : Abwärts";
          ft.MoveTo(ft.MotCntl[iTurm].actPos, ft.MotCntl[iSensor].maxPos);
          lblStatus.Text = "Turm : Fahren nach rechts";
          ft.MoveDelta(incTurm);
          lblStatus.Text = "Scan : Aufwärts";
          ft.MoveTo(ft.MotCntl[iTurm].actPos, 0);
          lblStatus.Text = "Turm : Fahren nach rechts";
          ft.MoveDelta(incTurm);
        }
        while (ft.MotCntl[iTurm].actPos > 0 && !ft.Finish()) {
          lblStatus.Text = "Scan : Abwärts";
          ft.MoveTo(ft.MotCntl[iTurm].actPos, ft.MotCntl[iSensor].maxPos);
          lblStatus.Text = "Turm : Fahren nach links";
          ft.MoveDelta(-incTurm);
          lblStatus.Text = "Scan : Aufwärts";
          ft.MoveTo(ft.MotCntl[iTurm].actPos, 0);
          lblStatus.Text = "Turm : Fahren nach links";
          ft.MoveDelta(-incTurm);
        }
      }
    }

    #region --- Programm-Kontrolle ---
    public UltraRadar() {
      InitializeComponent();
    }

    private void cmdAction_Click(object sender, EventArgs e) {
      ft.PositionChange += new FishRobot.CommonDelegate(PositionAusgabe);
      try {
        ft.OpenInterface(IFTypen.ftROBO_first_USB, 0, Distance.UltraSonic);
        cmdAction.Enabled = false;
        cmdEnde.Text = "&HALT";
        lblStatus.Text = "--- Bei der Arbeit ---";
        lblHinweis.Text = "--- Ende : HALT-Button oder ESC-Taste ---";
        Action(); 
        ft.ClearMotors();
      }
      catch (FishFaceException eft) {
        MessageBox.Show(eft.Message, this.Text,
          MessageBoxButtons.OK, MessageBoxIcon.Stop);
      }
      finally {
        ft.CloseInterface();
        cmdAction.Enabled = true;
        cmdEnde.Text = "&ENDE";
        lblStatus.Text = "--- Auf ein Neues ---";
        lblHinweis.Text = "Nochmal : ACTION, sonst ENDE oder ESC-Taste";
        cmdAction.Focus();
      }
    }

    private void cmdEnde_Click(object sender, EventArgs e) {
      if (cmdEnde.Text == "&HALT") ft.NotHalt = true; else this.Close();
    }

    private void formClosing(object sender, FormClosingEventArgs e) {
      if (cmdEnde.Text == "&HALT") e.Cancel = true;
    }
    #endregion
  }
}